/**
 * \file PageAdmin.xaml.cs
 * \brief Fonctionnalits administrateur
 * Code regroupant les fonctionnalits administrateur de l'application (gestion des jeux)
 */

using Microsoft.Maui.Controls;
using Models;
using System.Diagnostics;

namespace GameAtlas.Views;

/// <summary>
/// Code-Behind pour la page d'admin.
/// </summary>
public partial class PageAdmin : ContentPage
{
    /// <summary>
    /// Gestionnaire d'administration.
    /// </summary>
    public Manager AdminManager => (App.Current as App).MyManager;

    /// <summary>
    /// Constructeur de la page d'administration.
    /// </summary>
    public PageAdmin()
    {
        InitializeComponent();
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur la flche de retour en arrire.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    async void Back_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
    {
        await Navigation.PopAsync();
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le bouton d'ajout de jeu.
    /// Affiche une succession de pop-up pour remplir les champs un par un.
    /// Traite et vrifie les champs pour ajouter un jeu.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    private async void OnButtonClicked(object sender, EventArgs e)
    {
        string nom = string.Empty;
        string sortie = string.Empty;
        string plateformes = string.Empty;
        string developpeur = string.Empty;
        string editeur = string.Empty;
        string note = string.Empty;
        string nbTelechargement = string.Empty;
        string genre = string.Empty;
        string image = string.Empty;
        string resume = string.Empty;

        int etape = 1;
        bool annuler = false;

        while (etape <= 10 && !annuler)
        {
            switch (etape)
            {
                case 1:
                    nom = await DisplayPromptAsync("Informations sur le Jeu [1/10]", "Quel est le Titre ?", accept: "Suivant", cancel: "Annuler", placeholder: "GTA VI");
                    if (string.IsNullOrEmpty(nom))
                    {
                        annuler = true;
                    }
                    break;
                case 2:
                    resume = await DisplayPromptAsync("Informations sur le Jeu [2/10]", "Rsum du jeu", accept: "Suivant", cancel: "Annuler", placeholder: "Rsum du jeu");
                    if (string.IsNullOrEmpty(resume))
                    {
                        annuler = true;
                    }
                    break;
                case 3:
                    sortie = await DisplayPromptAsync("Informations sur le Jeu [3/10]", "Date de Sortie", accept: "Suivant", cancel: "Annuler", placeholder: "JJ/MM/AAAA");
                    if (string.IsNullOrEmpty(sortie))
                    {
                        annuler = true;
                    }
                    break;
                case 4:
                    plateformes = await DisplayPromptAsync("Informations sur le Jeu [4/10]", "Plateforme(s), un espace pour sparer", accept: "Suivant", cancel: "Annuler", placeholder: "Ex: XOne PC PS5");
                    if (string.IsNullOrEmpty(plateformes))
                    {
                        annuler = true;
                    }
                    break;
                case 5:
                    developpeur = await DisplayPromptAsync("Informations sur le Jeu [5/10]", "Dveloppeur", accept: "Suivant", cancel: "Annuler", placeholder: "Rockstar Games");
                    if (string.IsNullOrEmpty(developpeur))
                    {
                        annuler = true;
                    }
                    break;
                case 6:
                    editeur = await DisplayPromptAsync("Informations sur le Jeu [6/10]", "Editeur", accept: "Suivant", cancel: "Annuler", placeholder: "Take-Two Interactive");
                    if (string.IsNullOrEmpty(editeur))
                    {
                        annuler = true;
                    }
                    break;
                case 7:
                    note = await DisplayPromptAsync("Informations sur le Jeu [7/10]", "Note de 0  10",accept: "Suivant", cancel: "Annuler", maxLength: 3, placeholder: "4,5");
                    if (string.IsNullOrEmpty(note))
                    {
                        annuler = true;
                    }
                    break;
                case 8:
                    nbTelechargement = await DisplayPromptAsync("Informations sur le Jeu [8/10]", "Nombre de Tlchargements (en milliers, ex: 630k)", accept: "Suivant", cancel: "Annuler", placeholder: "630");
                    if (string.IsNullOrEmpty(nbTelechargement))
                    {
                        annuler = true;
                    }
                    break;
                case 9:
                    genre = await DisplayPromptAsync("Informations sur le Jeu [9/10]", "Genre(s), un espace pour sparer", accept: "Suivant", cancel: "Annuler", placeholder: "Action Aventure");
                    if (string.IsNullOrEmpty(genre))
                    {
                        annuler = true;
                    }
                    break;
                case 10:
                    image = await DisplayPromptAsync("Informations sur le Jeu [10/10]", "Image de couverture (prfrez URL finissant par .png)", accept: "Terminer", cancel: "Annuler", placeholder: "http://example.com/monimage.png");
                    if (string.IsNullOrEmpty(image))
                    {
                        annuler = true;
                    }
                    break;
            }

            etape++;
        }

        if (!annuler)
        {
            Jeu adminJeu = new Jeu(nom, resume, sortie, plateformes, developpeur, editeur, Convert.ToDouble(note), Convert.ToInt32(nbTelechargement), genre, image);
            AdminManager.AddJeux(adminJeu);
            AdminManager.SauvegardeDonnees();
            AdminManager.OnPropertyChanged(nameof(AdminManager.ListJeux));
            AdminManager.OnPropertyChanged(nameof(AdminManager.TopRatedGames));
            AdminManager.OnPropertyChanged(nameof(AdminManager.ListJeuxAffiches));

            Debug.WriteLine($"Le jeu \"{adminJeu.Nom}\" a t ajout.");
        }
        else
        {
            Debug.WriteLine("Annulation de l'ajout du jeu.");
        }
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le bouton de suppression d'un jeu.
    /// Affiche une liste de jeux  supprimer.
    /// Supprime le jeu slectionn.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    private async void OnDeleteClicked(object sender, EventArgs e)
    {
        var gameNames = GetGameNames().ToArray();
        string action = await DisplayActionSheet("Slectionnez un jeu  supprimer", "Annuler", null, gameNames);

        if (action != null && action != "Annuler")
        {
            var jeuASupprimer = GetGameByName(action);
            if (jeuASupprimer != null)
            {
                AdminManager.ListJeux.Remove(jeuASupprimer);
                AdminManager.SauvegardeDonnees();
                await DisplayAlert("Succs",$"{jeuASupprimer.Nom} a bien t supprim de l'application.", "Ok");
                Debug.WriteLine($"Le jeu {jeuASupprimer.Nom} a t supprim");
            }
        }
    }

    /// <summary>
    /// Retourne une liste de noms de jeux.
    /// </summary>
    /// <returns>La liste des noms de jeux.</returns>
    private List<string> GetGameNames()
    {
        return AdminManager.ListJeux.Select(jeu => jeu.Nom).ToList();
    }

    /// <summary>
    /// Retourne une liste de noms de jeux.
    /// </summary>
    /// <returns>La liste des noms de jeux.</returns>
    private Jeu GetGameByName(string name)
    {
        return AdminManager.ListJeux.FirstOrDefault(jeu => jeu.Nom == name);
    }

}