/**
 * \file PageConnexion.xaml.cs
 * \brief Systme de connexion
 * Systme de connexion avec vrification et chargement de l'utilisateur connect
 */

namespace GameAtlas.Views;

using Models;
using System.Diagnostics;
using System.Text.RegularExpressions;

/// <summary>
/// Code-Behind pour la page de connexion.
/// </summary>
public partial class PageConnexion : ContentPage
{

    private bool connexionWorked;

    /// <summary>
    /// Gestionnaire de connexion.
    /// </summary>
    public Manager ConnexionManager => (App.Current as App).MyManager;

    /// <summary>
    /// Constructeur de la page de connexion.
    /// </summary>
    public PageConnexion()
    {
        InitializeComponent();
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le bouton "Connexion".
    /// Vrifie les champs non vides et effectue la vrification de la connexion.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    private async void OnSignInClicked(object sender, EventArgs e)
    {

        string username = pseudo.Text;
        string password = mdp.Text;


        if (string.IsNullOrWhiteSpace(username) || string.IsNullOrWhiteSpace(password))
        {
            await DisplayAlert("Erreur", "Entrez tous les champs", "Ok");
            return;
        }

        connexionWorked = Verification(username, password);
        if (connexionWorked)
        {
            await Navigation.PopAsync();
        }
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le texte "S'inscrire".
    /// Affiche la page d'inscription.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    private async void OnInscrire_Tapped(object sender, EventArgs e)
    {
        await Navigation.PushModalAsync(new PageInscription());

    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le texte "Mot de Passe oubli".
    /// Affiche des pop-ups avec des messages.
    /// </summary>
    /// <param name="sender">L'objet qui a dclench l'vnement.</param>
    /// <param name="e">Les arguments de l'vnement.</param>
    private async void OnMotDePasseOublie_Tapped(object sender, EventArgs e)
    {
        await DisplayAlert("Oh non !", "Le mot de passe va te revenir  force", "Concentration");
        await DisplayAlert("Oh non !", "Encore un petit effort !", "Concentration");

        bool reponse = await DisplayAlert("Alors ?", "Tu l'as retrouv ce mot de passe ?", "Oui", "Non");
        if (!reponse)
        {
            await DisplayAlert("...", "Dsol on peut rien pour toi. La prochaine fois utilise un papier comme tout le monde.", "RIP");
        }
        else
        {
            await DisplayAlert("...", "C'est bien, la prochaine fois tu le notera.", "Ok");
        }
    }

    /// <summary>
    /// Vrifie la prsence de l'utilisateur dans la liste des utilisateurs et effectue la vrification du mot de passe.
    /// Charge l'utilisateur connect si la vrification est russie.
    /// Affiche un message d'erreur sinon.
    /// </summary>
    /// <param name="username">Le nom d'utilisateur saisi.</param>
    /// <param name="password">Le mot de passe saisi.</param>
    /// <returns>True si la connexion a russi, false sinon.</returns>
    public bool Verification(string username, string password)
    {
        foreach (Utilisateur user in ConnexionManager.Utilisateurs.Concat(ConnexionManager.Admins))
        {
            if (user.Pseudo == username)
            {
                Debug.WriteLine($"Pseudo \"{user.Pseudo}\" vrifi et valide");
                if (user.Mdp == password)
                {
                    Debug.WriteLine("Mot de Passe verifi et valide");
                    ConnexionManager.ConnectedUser = user;
                    ConnexionManager.IsConnected = true;
                    return true;
                }
            }
        }
        Debug.WriteLine("La connexion a chou (pseudo ou mot de passe invalide)");
        DisplayAlert("Erreur", "Utilisateur ou Mot de Passe invalide.", "Ok");
        ConnexionManager.ConnectedUser = null;
        ConnexionManager.IsConnected = false;
        return false;
    }

}