namespace GameAtlas.Views;

using Models;
using DataContractPersistance;
using System.Diagnostics;
using System.Text.RegularExpressions;
using CommunityToolkit.Maui.Core;
using CommunityToolkit.Maui.Alerts;
using Font = Microsoft.Maui.Font;

/// <summary>
/// Code-Behind pour la page d'inscription.
/// </summary>
public partial class PageInscription : ContentPage
{
    /// <summary>
    /// Chemin d'accs  l'image par dfaut pour le profil utilisateur.
    /// </summary>
    string ImagePath {  get; set; } = "default_user.png";

    /// <summary>
    /// Gestionnaire d'inscription.
    /// </summary>
    public Manager InscriptionManager => (App.Current as App).MyManager;

    /// <summary>
    /// Constructeur de la page d'inscription.
    /// </summary>
    public PageInscription()
	{
		InitializeComponent();
	}

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le bouton "S'inscrire".
    /// </summary>
    private async void OnSignUpClicked(object sender, EventArgs e)
    {

        string mail = email.Text;
        string username = pseudo.Text;
        string password = mdp.Text;


        if(string.IsNullOrWhiteSpace(mail) || string.IsNullOrWhiteSpace(username) || string.IsNullOrWhiteSpace(password))
        {
            await DisplayAlert("Erreur", "Entrez tous les champs", "Ok");
            return;
        }

        else if (!Regex.IsMatch(mail, @"^[a-zA-Z][\w\.-]*[a-zA-Z0-9]@[a-zA-Z0-9][\w\.-]*[a-zA-Z0-9]\.[a-zA-Z][a-zA-Z\.]*[a-zA-Z]$"))
        {
            await DisplayAlert("Erreur","Email non valide","Ok");
            return;
        }

        if (IsPasswordStrong(password) == false)
        {
            await DisplayAlert("Erreur", "Le mot de passe n'est pas assez fort", "OK");
            return;
        }

        Utilisateur utilisateur = new Utilisateur(mail, username, password);
        utilisateur.PhotoProfil = ImagePath;
        InscriptionManager.AddUtilisateur(utilisateur);
        InscriptionManager.SauvegardeDonnees();
        Debug.WriteLine(InscriptionManager.Utilisateurs.Count);

        await DisplayAlert("Compte crer avec succs !","Vous pouvez maintenant vous connecter.", cancel: "Ok");
        await Shell.Current.GoToAsync("//page/PageAccueil");
    }

    /// <summary>
    /// Vrifie si le mot de passe est assez fort.
    /// </summary>
    /// <param name="password">Le mot de passe  vrifier.</param>
    /// <returns>True si le mot de passe est assez fort, False sinon.</returns>
    bool IsPasswordStrong(string password)
    {
        // Vrifier si le mot de passe est assez long
        if (password.Length < 8)
        {
            return false;
        }

        // Vrifier si le mot de passe contient au moins une majuscule, une minuscule et un chiffre
        bool hasUppercase = false;
        bool hasLowercase = false;
        bool hasDigit = false;

        foreach (char c in password)
        {
            if (char.IsUpper(c))
            {
                hasUppercase = true;
            }
            else if (char.IsLower(c))
            {
                hasLowercase = true;
            }
            else if (char.IsDigit(c))
            {
                hasDigit = true;
            }
        }

        return hasUppercase && hasLowercase && hasDigit;
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur le bouton "Slectionner une photo".
    /// </summary>
    private async void OnSelectPhotoClicked(object sender, EventArgs e)
    {
        var photo = await MediaPicker.PickPhotoAsync();

        if (photo != null)
        {
            ImagePath = photo.FullPath;
        }
        else
        {
            ImagePath = "default_user.png";
        }
    }
}