namespace GameAtlas.Views
{
    using Models;
    using System.Collections.ObjectModel;

    /// <summary>
    /// Code-Behind pour la page parcourir.
    /// </summary>
    public partial class PageParcourir : ContentPage
    {
        /// <summary>
        /// Gestionnaire de parcours.
        /// </summary>
        public Manager ParcourirManager => (App.Current as App).MyManager;

        /// <summary>
        /// Constructeur de la page de parcours.
        /// </summary>
        public PageParcourir()
        {
            InitializeComponent();
            BindingContext = ParcourirManager;
        }

        /// <summary>
        /// Mthode appele lorsqu'un jeu est slectionn.
        /// </summary>
        async void OnGame_Tapped(System.Object sender, EventArgs e)
        {
            var selectedjeu = (sender as ImageButton)?.BindingContext as Jeu;
            if (selectedjeu != null)
            {
                await Navigation.PushAsync(new PageJeu(selectedjeu));
            }
        }

        /// <summary>
        /// Mthode appele lorsqu'on appuie sur l'icne de retour.
        /// </summary>
        async void Back_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
        {
            await Navigation.PopAsync();
        }

        /// <summary>
        /// Mthode appele lorsque le texte de la barre de recherche change.
        /// </summary>
        private void SearchBar_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (string.IsNullOrWhiteSpace(e.NewTextValue))
            {
                searchResults.ItemsSource = ParcourirManager.ListJeux;
            }
            else
            {
                searchResults.ItemsSource = ParcourirManager.ListJeux.Where(i => i.Nom.ToLower().Contains(e.NewTextValue.ToLower()));
            }
        }
    }
}
