using Models;

namespace GameAtlas.Views;

/// <summary>
/// Code-Behind pour la page de profil.
/// </summary>
public partial class PageProfil : ContentPage
{
    /// <summary>
    /// Gestionnaire de profil. Manager
    /// </summary>
    public Manager ProfilManager => (App.Current as App).MyManager;

    /// <summary>
    /// Constructeur de la page de profil.
    /// </summary>
    public PageProfil()
	{
		InitializeComponent();
        BindingContext = ProfilManager;
    }

    /// <summary>
    /// Mthode appele lorsque la page est affiche.
    /// </summary>
    protected override void OnAppearing()
    {
        base.OnAppearing();
        SwitchPage();
    }

    /// <summary>
    /// Mthode pour basculer vers une autre page en fonction de l'utilisateur connect.
    /// </summary>
    async void SwitchPage()
    {
        if (ProfilManager.ConnectedUser == null)
        {
            await Navigation.PushAsync(new PageConnexion());
        }
        else
        {
            await Shell.Current.GoToAsync("//page/PageProfil");
        }
    }

    /// <summary>
    /// Mthode appele lorsqu'un jeu est slectionn.
    /// </summary>
    async void OnGame_Tapped(System.Object sender, EventArgs e)
    {
        var selectedjeu = (sender as ImageButton)?.BindingContext as Jeu;
        if (selectedjeu != null)
        {
            
            await Navigation.PushAsync(new PageJeu(selectedjeu));
        }
       
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur l'icne d'administration.
    /// </summary>
    async void OnAdmin_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
    {
        await Shell.Current.GoToAsync(nameof(PageAdmin));
    }

    /// <summary>
    /// Mthode appele lorsqu'on appuie sur l'icne de dconnexion.
    /// </summary>
    async void OnDisconnect_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
    {
        await Shell.Current.GoToAsync("//page/PageAccueil");
        ProfilManager.ConnectedUser = null;
        ProfilManager.IsConnected = false;
    }
}