using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Models
{
    /// <summary>
    /// Interface pour la gestion de la persistance des donnes.
    /// </summary>
    public interface IPersistanceManager
    {
        /// <summary>
        /// Charge les donnes persistantes.
        /// </summary>
        /// <returns>Un tuple contenant les collections de jeux, d'administrateurs et d'utilisateurs charges.</returns>
        (ObservableCollection<Jeu>, List<Admin>, List<Utilisateur>) ChargeDonnees();

        /// <summary>
        /// Sauvegarde les donnes persistantes.
        /// </summary>
        /// <param name="jeux">La collection de jeux  sauvegarder.</param>
        /// <param name="admins">La liste des administrateurs  sauvegarder.</param>
        /// <param name="utilisateurs">La liste des utilisateurs  sauvegarder.</param>
        void SauvegardeDonnees(ObservableCollection<Jeu> jeux, List<Admin> admins, List<Utilisateur> utilisateurs);
    }

}