﻿/// \file
/// \brief Définition de la classe Utilisateur.
/// \author Rémi Lavergne - Yvan Calatayud

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace Models
{
    /// <summary>
    /// Représente un Utilisateur de l'application.
    /// </summary>
    [DataContract]
    [KnownType(typeof(Admin))]
    public class Utilisateur
    {
        /// <summary>
        /// Obtient l'adresse e-mail de l'utilisateur.
        /// </summary>
        [DataMember]
        public string Mail { get; private set; }

        /// <summary>
        /// Obtient le pseudo de l'utilisateur.
        /// </summary>
        [DataMember]
        public string Pseudo { get; private set; }

        /// <summary>
        /// Obtient le mot de passe de l'utilisateur.
        /// </summary>
        [DataMember]
        public string Mdp { get; private set; }

        /// <summary>
        /// Obtient ou définit la photo de profil de l'utilisateur.
        /// </summary>
        [DataMember]
        public string PhotoProfil { get; set; }

        /// <summary>
        /// Obtient la date de création de l'utilisateur.
        /// </summary>
        [DataMember]
        public string DateCreation { get; private set; }

        /// <summary>
        /// Obtient ou définit une valeur indiquant si l'utilisateur est un administrateur.
        /// </summary>
        [DataMember]
        public bool EstAdmin { get; set; }

        /// <summary>
        /// Obtient la liste des jeux possédés par l'utilisateur.
        /// </summary>
        [DataMember]
        public ObservableCollection<Jeu> ListePossedes { get; private set; }

        /// <summary>
        /// Obtient la liste des jeux favoris de l'utilisateur.
        /// </summary>
        [DataMember]
        public ObservableCollection<Jeu> ListeFavoris { get; private set; }

        /// <summary>
        /// Obtient ou définit le nombre d'avis donnés par l'utilisateur.
        /// </summary>
        [DataMember]
        public int NbAvis { get; set; }

        /// <summary>
        /// Constructeur qui initialise une nouvelle instance de la classe <see cref="Utilisateur"/>.
        /// </summary>
        /// <param name="mail">L'adresse e-mail de l'utilisateur.</param>
        /// <param name="pseudo">Le pseudo de l'utilisateur.</param>
        /// <param name="mdp">Le mot de passe de l'utilisateur.</param>
        public Utilisateur(string mail, string pseudo, string mdp)
        {
            Mail = mail;
            Pseudo = pseudo;
            Mdp = mdp;
            PhotoProfil = "default_user.png";
            DateCreation = DateTime.Today.ToString("d");
            ListePossedes = new ObservableCollection<Jeu>();
            ListeFavoris = new ObservableCollection<Jeu>();
            EstAdmin = false;
            NbAvis = 0;
        }
    }
}
