﻿using Models;
using System.Collections.ObjectModel;
using System.Linq;

namespace Tests
{
    public class ManagerTest
    {
        [Fact]
        public void Manager_AddJeux()
        {
            
            var manager = new Manager();
            var jeu = new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png");


            manager.AddJeux(jeu);

            // Assert
            Assert.Contains(jeu, manager.ListJeux);
        }

        [Fact]
        public void Manager_AddAdmin()
        {
            
            var manager = new Manager();
            var admin = new Admin("admin@example.com", "adminuser", "password");

            
            manager.AddAdmin(admin);

            // Assert
            Assert.Contains(admin, manager.Admins);
        }

        [Fact]
        public void Manager_AddUtilisateur()
        {
            
            var manager = new Manager();
            var utilisateur = new Utilisateur("user@example.com", "user", "password");

            
            manager.AddUtilisateur(utilisateur);

            // Assert
            Assert.Contains(utilisateur, manager.Utilisateurs);
        }

        [Fact]
        public void Manager_ChargerDonnees()
        {
            
            var manager = new Manager();
            var persistanceManager = new PersistanceManager();
            var jeux = new ObservableCollection<Jeu>()
            {
                new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png"),
                new Jeu("Un Autre Jeu", "Autre Description", "10 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png")
            };
            var admins = new List<Admin>()
            {
                new Admin("admin1@example.com", "admin1", "password1"),
                new Admin("admin2@example.com", "admin2", "password2")
            };
            var utilisateurs = new List<Utilisateur>()
            {
                new Utilisateur("user1@example.com", "user1", "password1"),
                new Utilisateur("user2@example.com", "user2", "password2")
            };
            persistanceManager.SetDonnees(jeux, admins, utilisateurs);
            manager.Persistance = persistanceManager;

            
            manager.ChargerDonnees();

            // Assert
            Assert.Equal(jeux, manager.ListJeux);
            Assert.Equal(admins, manager.Admins.ToList()); // Convertit en List<T>
            Assert.Equal(utilisateurs, manager.Utilisateurs.ToList()); // Convertit en List<T>
        }

        [Fact]
        public void Manager_SauvegardeDonnees()
        {
            
            var manager = new Manager();
            var persistanceManager = new PersistanceManager();
            var jeux = new ObservableCollection<Jeu>()
            {
                new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png"),
                new Jeu("Un Autre Jeu", "Autre Description", "10 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png")
            };
            var admins = new List<Admin>()
            {
                new Admin("admin1@example.com", "admin1", "password1"),
                new Admin("admin2@example.com", "admin2", "password2")
            };
            var utilisateurs = new List<Utilisateur>()
            {
                new Utilisateur("user1@example.com", "user1", "password1"),
                new Utilisateur("user2@example.com", "user2", "password2")
            };
            manager.ListJeux = jeux;
            foreach (var admin in admins)
            {
                manager.AddAdmin(admin);
            }
            foreach (var utilisateur in utilisateurs)
            {
                manager.AddUtilisateur(utilisateur);
            }
            manager.Persistance = persistanceManager;

            
            manager.SauvegardeDonnees();

            // Assert
            Assert.Equal(jeux, persistanceManager.Jeux);
            Assert.Equal(admins, persistanceManager.Admins);
            Assert.Equal(utilisateurs, persistanceManager.Utilisateurs);
        }
    }

    public class PersistanceManager : IPersistanceManager
    {
        public ObservableCollection<Jeu>? Jeux { get; private set; }
        public List<Admin>? Admins { get; private set; }
        public List<Utilisateur>? Utilisateurs { get; private set; }

        public void SetDonnees(ObservableCollection<Jeu> jeux, List<Admin> admins, List<Utilisateur> utilisateurs)
        {
            Jeux = jeux;
            Admins = admins;
            Utilisateurs = utilisateurs;
        }

        public (ObservableCollection<Jeu>, List<Admin>, List<Utilisateur>) ChargeDonnees()
        {
            return (Jeux!, Admins!, Utilisateurs!);
        }

        public void SauvegardeDonnees(ObservableCollection<Jeu> jeux, List<Admin> admins, List<Utilisateur> utilisateurs)
        {
            Jeux = jeux;
            Admins = admins;
            Utilisateurs = utilisateurs;
        }
    }
}
